import random
import uuid

from autofaker.base import TypeDataGeneratorBase


class IntegerGenerator(TypeDataGeneratorBase):
    def generate(self):
        return random.randint(0, 10000)


class StringGenerator(TypeDataGeneratorBase):
    def generate(self):
        return str(uuid.uuid4())


class FloatGenerator(TypeDataGeneratorBase):
    def generate(self):
        return random.uniform(0, 10000)


class BooleanGenerator(TypeDataGeneratorBase):
    def generate(self):
        return bool(random.getrandbits(1))



import unittest

from autofaker import Autodata


class AnonymousSimpleClassTestCase(unittest.TestCase):

    def test_create_local_class_returns_not_none(self):
        class X:
            pass

        self.assertIsNotNone(Autodata.create(X))

    def test_create_local_class_returns_instance(self):
        class X:
            pass

        self.assertIsInstance(Autodata.create(X), X)

    def test_create_simple_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(SimpleClass))

    def test_create_simple_class_returns_instance(self):
        self.assertIsInstance(Autodata.create(SimpleClass), SimpleClass)

    def test_create_simple_class_returns_instance_with_new_values(self):
        result = Autodata.create(SimpleClass)
        self.assertNotEqual(result.id, SimpleClass().id)
        self.assertNotEqual(result.text, SimpleClass().text)


class SimpleClass:
    id = 123
    text = 'test'



import unittest

from autofaker import Autodata


class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):

    def test_create_arguments_throws_error_when_decorating_non_testmethod(self):
        with self.assertRaises(NotImplementedError):
            class X:
                @Autodata.create_arguments(str, str, str)
                def not_test_method(self):
                    pass
            X().not_test_method()

    def test_create_arguments_throws_error_when_used_without_arguments(self):
        with self.assertRaises(NotImplementedError):
            class X:
                @Autodata.create_arguments()
                def not_test_method(self):
                    pass
            X().not_test_method()

    def test_create_arguments_throws_error_when_used_without_arguments_annotation(self):
        with self.assertRaises(ValueError):
            class X(unittest.TestCase):
                @Autodata.create_arguments()
                def not_test_method(self, text, number, decimal):
                    pass
            X().not_test_method()



import pandas as pd

from autofaker.attributes import Attributes
from autofaker.generator import TypeDataGenerator


class PandasDataFrameGenerator:
    """
    Create a Pandas DataFrame containing anonymous data with the specified number of rows (default 3)
    """

    def __init__(self, t, rows: int = 3, use_fake_data: bool = False):
        """
        Create a Pandas DataFrame containing anonymous data with the specified number of rows (default 3)

        :type rows: int
        :type t: object
        :type use_fake_data: bool
        """
        self.__data = []
        for _ in range(rows):
            self.__data.append(TypeDataGenerator.create(t, use_fake_data=use_fake_data).generate())

    def generate(self):
        members = Attributes(self.__data[0]).get_members()
        rows = []
        for d in self.__data:
            row = []
            for member in members:
                row.append(Attributes(d).get_attribute(member))
            rows.append(row)
        return pd.DataFrame(rows, columns=members)


class SparkDataFrameGenerator:
    """
    Create a Spark DataFrame containing anonymous data with the specified number of rows (default 3)
    """

    def __init__(self, t, rows: int = 3, use_fake_data: bool = False):
        """
        Create a Pandas DataFrame containing anonymous data with the specified number of rows (default 3)

        :type rows: int
        :type t: object
        :type use_fake_data: bool
        """
        self.use_fake_data = use_fake_data
        self.t = t
        self.rows = rows

    def generate(self):
        from pyspark.sql import SparkSession
        pdf = PandasDataFrameGenerator(self.t, self.rows, use_fake_data=self.use_fake_data).generate()
        spark = SparkSession.builder.getOrCreate()
        return spark.createDataFrame(pdf)



import unittest
from typing import List

from autofaker import Autodata


class Calculator:
  def add(self, number1: int, number2: int):
    return number1 + number2


class CalculatorTests(unittest.TestCase):

    def test_can_add_two_numbers(self):
        numbers = Autodata.create_many(int, 2)
        sut = Autodata.create(Calculator)
        result = sut.add(numbers[0], numbers[1])
        self.assertEqual(numbers[0] + numbers[1], result)

    @Autodata.create_arguments(Calculator, int, int)
    def test_can_add_two_numbers_using_test_arguments(self, sut, number1, number2):
        result = sut.add(number1, number2)
        self.assertEqual(number1 + number2, result)

    @Autodata.create_arguments()
    def test_can_add_two_numbers_using_annotated_arguments(self, sut: Calculator, number1: int, number2: int):
        result = sut.add(number1, number2)
        self.assertEqual(number1 + number2, result)

    @Autodata.create_anonymous_arguments
    def test_can_add_two_numbers_using_anonymous_arguments(self, sut: Calculator, number1: int, number2: int):
        result = sut.add(number1, number2)
        self.assertEqual(number1 + number2, result)

    @Autodata.create_fake_arguments
    def test_can_add_two_numbers_using_fake_arguments(self, sut: Calculator, number1: int, number2: int):
        result = sut.add(number1, number2)
        self.assertEqual(number1 + number2, result)


class Person:
    age = 10
    name = 'test'

    def get_introduction(self):
        return f"Hi! My name is {self.name} and I'm {self.age} years old"


class Staff:
    def __init__(self):
        self.people = []

    def add_person(self, person: Person):
        self.people.append(person)

    def add_people(self, people: List[Person]):
        for person in people:
            self.add_person(person)

    def get_head_count(self):
        return len(self.people)

    def introduce(self):
        for person in self.people:
            print(person.get_introduction())


class StaffTests(unittest.TestCase):

    def test_introduce_everyone(self):
        people = Autodata.create_many(Person)
        sut = Autodata.create(Staff)
        sut.add_people(people)
        sut.introduce()
        self.assertEqual(len(people), sut.get_head_count())



import random
import unittest
from abc import abstractmethod

from autofaker import Autodata


class CreateManyTestCase(unittest.TestCase):
    @abstractmethod
    def getType(self):
        pass

    def test_create_many_returns_not_none(self):
        if self.getType() is None:
            return
        self.assertIsNotNone(Autodata.create_many(self.getType()))

    def test_create_many_returns_list(self):
        if self.getType() is None:
            return
        self.assertIsInstance(Autodata.create_many(self.getType()), list)

    def test_create_many_with_size_returns(self):
        if self.getType() is None:
            return
        size = random.randint(1, 10)
        self.assertEqual(len(Autodata.create_many(self.getType(), size)), size)

    def test_create_many_returns_non_default(self):
        if self.getType() is None:
            return
        self.assertNotEqual(Autodata.create_many(self.getType()), [self.getType()()])


class AnonymousStringListTestCase(CreateManyTestCase):
    def getType(self):
        return str


class AnonymousIntegerListTestCase(CreateManyTestCase):
    def getType(self):
        return int


class AnonymousFloatListTestCase(CreateManyTestCase):
    def getType(self):
        return float


class AnonymousBooleanListTestCase(CreateManyTestCase):
    def getType(self):
        return bool



import sys
import unittest
from dataclasses import dataclass

from autofaker import Autodata


@dataclass
class DataClass:
    id: int

    name: str
    first_name: str
    last_name: str
    address: str
    job: str

    country: str
    currency_name: str
    currency_code: str

    email: str
    safe_email: str
    company_email: str

    hostname: str
    ipv4: str
    ipv6: str

    text: str
    word: str


def is_uuid(s: str):
    try:
        from uuid import UUID
        UUID(s)
        return True
    except ValueError:
        return False


class AnonymousDataClassWithFakesTestCase(unittest.TestCase):

    def test_create_pandas_dataframe_returns_not_none(self):
        pdf = Autodata.create_pandas_dataframe(DataClass, use_fake_data=True)
        print()
        print(pdf)
        self.assertIsNotNone(pdf)

    @unittest.skipIf(sys.platform.startswith("win") or sys.platform == "darwin", "tests are very slow")
    def test_create_spark_dataframe_returns_not_none(self):
        df = Autodata.create_spark_dataframe(DataClass, use_fake_data=True)
        self.assertIsNotNone(df)



import dataclasses
import unittest
from dataclasses import dataclass

from autofaker import Autodata


@dataclass
class DataClass:
    id: int
    text: str


class AnonymousDataClassTestCase(unittest.TestCase):

    def test_create_data_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(DataClass))

    def test_create_data_class_returns_dataclass(self):
        self.assertTrue(dataclasses.is_dataclass(Autodata.create(DataClass)))

    def test_create_many_data_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create_many(DataClass))

    def test_create_many_data_class_returns_list(self):
        self.assertIsInstance(Autodata.create_many(DataClass), list)

    def test_create_many_data_class_returns_dataclass(self):
        data = Autodata.create(DataClass)
        self.assertNotEqual(0, data.id)
        self.assertNotEqual('', data.text)


@dataclass
class NestedDataClass:
    id: int
    text: str
    inner: DataClass


class AnonymousNestedClassTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedDataClass))

    def test_create_data_class_returns_dataclass(self):
        self.assertTrue(dataclasses.is_dataclass(Autodata.create(NestedDataClass)))

    def test_create_nested_class_returns_instance_with_nested_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedDataClass).inner)

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(NestedDataClass)
        self.assertNotEqual(result.id, 0)
        self.assertNotEqual(result.inner.id, 0)
        self.assertNotEqual(result.inner.text, '')


@dataclass
class DoubleNestedDataClass:
    id: int
    text: str
    inner: NestedDataClass


class AnonymousDoubleNestedDataClassTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(DoubleNestedDataClass))

    def test_create_data_class_returns_dataclass(self):
        self.assertTrue(dataclasses.is_dataclass(Autodata.create(DoubleNestedDataClass)))

    def test_create_nested_class_returns_instance_with_nested_not_none(self):
        self.assertIsNotNone(Autodata.create(DoubleNestedDataClass).inner)

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(DoubleNestedDataClass)
        self.assertNotEqual(result.id, 0)
        self.assertNotEqual(result.inner.id, 0)
        self.assertNotEqual(result.inner.text, '')
        self.assertNotEqual(result.inner.inner.id, 0)
        self.assertNotEqual(result.inner.inner.text, '')


class AnonymousInlineDataClassTestCase(unittest.TestCase):

    def test_create_data_class_returns_not_none(self):
        @dataclass
        class InlineDataClass:
            id: int
            text: str
        self.assertIsNotNone(Autodata.create(InlineDataClass))

    def test_create_data_class_returns_dataclass(self):
        @dataclass
        class InlineDataClass:
            id: int
            text: str
        self.assertTrue(dataclasses.is_dataclass(Autodata.create(InlineDataClass)))

    def test_create_many_data_class_returns_not_none(self):
        @dataclass
        class InlineDataClass:
            id: int
            text: str
        self.assertIsNotNone(Autodata.create_many(InlineDataClass))

    def test_create_many_data_class_returns_list(self):
        @dataclass
        class InlineDataClass:
            id: int
            text: str
        self.assertIsInstance(Autodata.create_many(InlineDataClass), list)

    def test_create_many_data_class_returns_dataclass(self):
        @dataclass
        class InlineDataClass:
            id: int
            text: str
        data = Autodata.create(InlineDataClass)
        self.assertNotEqual(0, data.id)
        self.assertNotEqual('', data.text)



import unittest
from dataclasses import dataclass

from autofaker import Autodata


@dataclass
class DataClass:
    id: int

    name: str
    first_name: str
    last_name: str
    address: str
    job: str

    country: str
    currency_name: str
    currency_code: str

    email: str
    safe_email: str
    company_email: str

    hostname: str
    ipv4: str
    ipv6: str

    text: str
    word: str


def is_uuid(s: str):
    try:
        from uuid import UUID
        UUID(s)
        return True
    except ValueError:
        return False


class AnonymousDataClassWithFakesTestCase(unittest.TestCase):

    def test_create_dataclass_name_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).name))

    def test_create_dataclass_first_name_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).first_name))

    def test_create_dataclass_last_name_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).last_name))

    def test_create_dataclass_address_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).address))

    def test_create_dataclass_job_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).job))

    def test_create_dataclass_country_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).country))

    def test_create_dataclass_currency_name_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).currency_name))

    def test_create_dataclass_currency_code_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).currency_code))

    def test_create_dataclass_email_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).email))

    def test_create_dataclass_safe_email_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).safe_email))

    def test_create_dataclass_company_email_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).company_email))

    def test_create_dataclass_hostname_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).hostname))

    def test_create_dataclass_ipv4_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).ipv4))

    def test_create_dataclass_ipv6_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).ipv6))

    def test_create_dataclass_text_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).text))

    def test_create_dataclass_word_returns_not_uuid(self):
        self.assertFalse(is_uuid(Autodata.create(DataClass, use_fake_data=True).word))



import random
import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    text = 'test'


class AnonymousSimpleClassTestCase(unittest.TestCase):
    def test_create_many_returns_not_none(self):
        self.assertIsNotNone(Autodata.create_many(SimpleClass))

    def test_create_many_returns_list(self):
        self.assertIsInstance(Autodata.create_many(SimpleClass), list)

    def test_create_many_with_size_returns(self):
        size = random.randint(1, 10)
        self.assertEqual(len(Autodata.create_many(SimpleClass, size)), size)

    def test_create_many_returns_non_default(self):
        self.assertNotEqual(Autodata.create_many(SimpleClass), [SimpleClass()])

    def test_create_many_local_class_returns_not_none(self):
        class X:
            pass
        self.assertIsNotNone(Autodata.create_many(X))

    def test_create_many_local_class_returns_instance(self):
        class X:
            pass
        self.assertIsInstance(Autodata.create_many(X), list)

    def test_create_many_local_returns_non_default(self):
        class X:
            pass
        self.assertNotEqual(Autodata.create_many(X), [X()])



import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    text = 'test'


class NestedWithCollectionClass:
    id = 123
    text = 'test'
    inner = [SimpleClass(), SimpleClass()]


class NestedWithNestedCollectionClass:
    id = 123
    text = 'test'
    inner = [NestedWithCollectionClass(), NestedWithCollectionClass()]


class AnonymousNestedClassWithCollectionTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedWithCollectionClass))

    def test_create_nested_class_returns_instance(self):
        self.assertIsInstance(Autodata.create(NestedWithCollectionClass), NestedWithCollectionClass)

    def test_create_nested_class_returns_instance_with_nested_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedWithCollectionClass).inner)

    def test_create_nested_class_returns_instance_with_nested_not_empty(self):
        self.assertNotEqual(0, len(Autodata.create(NestedWithCollectionClass).inner))

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(NestedWithCollectionClass)
        self.assertNotEqual(result.id, NestedWithCollectionClass().id)
        for cls in result.inner:
            self.assertIsNotNone(cls)
            self.assertNotEqual(cls.id, SimpleClass().id)
            self.assertNotEqual(cls.text, SimpleClass().text)


class AnonymousNestedClassWithNestedCollectionTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedWithCollectionClass))

    def test_create_nested_class_returns_instance(self):
        self.assertIsInstance(Autodata.create(NestedWithCollectionClass), NestedWithCollectionClass)

    def test_create_nested_class_returns_instance_with_inner_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedWithNestedCollectionClass).inner)

    def test_create_nested_class_returns_instance_with_inner_not_empty(self):
        self.assertNotEqual(0, len(Autodata.create(NestedWithNestedCollectionClass).inner))

    def test_create_nested_class_returns_instance_with_nested_inner_not_empty(self):
        self.assertNotEqual(0, len(Autodata.create(NestedWithNestedCollectionClass).inner[0].inner))

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(NestedWithNestedCollectionClass)
        self.assertNotEqual(result.id, NestedWithNestedCollectionClass().id)
        self.assertNotEqual(result.text, NestedWithNestedCollectionClass().text)
        for cls in result.inner:
            self.assertIsNotNone(cls)
            self.assertNotEqual(cls.id, NestedWithCollectionClass().id)
            self.assertNotEqual(cls.text, NestedWithCollectionClass().text)
            for inner in cls.inner:
                self.assertNotEqual(inner.id, SimpleClass().id)
                self.assertNotEqual(inner.text, SimpleClass().text)



"""
Provides classes for anonymous object creation to help minimize the setup/arrange phase when writing unit tests
"""

import typing
import unittest
from typing import List
import inspect

from pyspark.sql import DataFrame

from autofaker.dataframe import PandasDataFrameGenerator, SparkDataFrameGenerator
from autofaker.generator import TypeDataGenerator


class Autodata:
    """
    Provides anonymous object creation functions to help minimize the setup/arrange phase when writing unit tests
    """

    @staticmethod
    def create(t, use_fake_data: bool = False):
        """
        Creates an anonymous variable of the requested type

        :param use_fake_data:
        :type t: object
        """
        return TypeDataGenerator.create(t, use_fake_data=use_fake_data).generate()

    @staticmethod
    def create_many(t, size: int = 3, use_fake_data: bool = False) -> List[typing.Any]:
        """
        Creates a list of anonymous variables of the requested type using the specified length (default 3)

        :param use_fake_data:
        :type size: int
        :type t: object
        """
        items = []
        for _ in range(size):
            items.append(Autodata.create(t, use_fake_data=use_fake_data))
        return items

    @staticmethod
    def create_pandas_dataframe(t, rows: int = 3, use_fake_data: bool = False):
        """
        Create a Pandas DataFrame containing anonymous data with the specified number of rows (default 3)

        :param use_fake_data:
        :type rows: int
        :type t: object
        """
        return PandasDataFrameGenerator(t, rows, use_fake_data=use_fake_data).generate()

    @staticmethod
    def create_spark_dataframe(t, rows: int = 3, use_fake_data: bool = False) -> DataFrame:
        """
        Create a Spark DataFrame containing anonymous data with the specified number of rows (default 3)

        :param use_fake_data:
        :type rows: int
        :type t: object
        """
        return SparkDataFrameGenerator(t, rows, use_fake_data=use_fake_data).generate()

    @staticmethod
    def create_arguments(*types: object, use_fake_data: bool = False):
        """
        Creates anonymous variable of the requested types and pass them as arguments to a unit test function

        Example:

        import unittest

        from autofaker import Autodata

        class SampleTest(unittest.TestCase):
            @Autodata.create_arguments(str, int, float, bool)

            def test_create_str_argument_using_decorator(self, text, number, decimal, boolean):
                self.assertIsNotNone(text)


        :param use_fake_data:
        :type types: tuple
        """
        def decorator(function):
            def wrapper(*args):
                return function(get_test_class(*args),
                                *tuple(create_function_args(function, *tuple(types), use_fake_data=use_fake_data)))
            return wrapper
        return decorator

    @staticmethod
    def create_anonymous_arguments(function):
        """
        Creates anonymous variable of the requested types and pass them as arguments to a unit test function

        Example:

        import unittest

        from autofaker import Autodata

        class SampleTest(unittest.TestCase):
            @Autodata.create_anonymous_arguments

            def test_create_anonymous_arguments(self, text: str, number: int, decimal: float, boolean: bool):
                self.assertIsNotNone(text)
        """
        def wrapper(*args):
            return function(get_test_class(*args),
                            *tuple(create_function_args(function)))
        return wrapper

    @staticmethod
    def create_fake_arguments(function):
        """
        Creates fake values for the variables of the requested types and pass them as arguments to a unit test function

        Example:

        import unittest

        from autofaker import Autodata

        class SampleTest(unittest.TestCase):
            @Autodata.create_fake_arguments

            def test_create_fake_arguments(self, text: str, number: int, decimal: float, boolean: bool):
                self.assertIsNotNone(text)
        """
        def wrapper(*args):
            return function(get_test_class(*args),
                            *tuple(create_function_args(function, use_fake_data=True)))
        return wrapper


def get_test_class(*args):
    if len(args) == 0:
        raise NotImplementedError("This way of creating anonymous objects are only supported from unit tests")
    test_class = args[0]
    if issubclass(test_class.__class__, unittest.TestCase) is False:
        raise NotImplementedError("This way of creating anonymous objects are only supported from unit tests")
    return test_class


def create_function_args(function, *types, use_fake_data: bool = False) -> List:
    values = []
    argtpes = inspect.getfullargspec(function)
    args = argtpes.annotations.values() if types is None or len(types) == 0 else types
    for t in args:
        value = Autodata.create(t, use_fake_data)
        values.append(value)
    if len(argtpes.args) - 1 != len(values):
        raise ValueError("Missing argument annotations. Please declare the type of every argument")
    return values



import unittest
from abc import abstractmethod
from datetime import date, datetime
import random

from autofaker import Autodata


class CreateManyTestCase(unittest.TestCase):
    @abstractmethod
    def getType(self):
        pass

    def test_create_many_returns_not_none(self):
        if self.getType() is None:
            return
        self.assertIsNotNone(Autodata.create_many(self.getType()))

    def test_create_many_returns_returns_list(self):
        if self.getType() is None:
            return
        self.assertIsInstance(Autodata.create_many(self.getType()), list)

    def test_create_many_with_size_returns(self):
        if self.getType() is None:
            return
        size = random.randint(1, 10)
        self.assertEqual(len(Autodata.create_many(self.getType(), size)), size)

    def test_create_many_returns_list_with_non_defaults(self):
        if self.getType() is None:
            return
        self.assertNotEqual(Autodata.create_many(self.getType()), [self.getType()(1970, 1, 1)])


class AnonymousDatetimeListTestCase(CreateManyTestCase):
    def getType(self):
        return datetime


class AnonymousDateListTestCase(CreateManyTestCase):
    def getType(self):
        return date



import setuptools

with open('docs/pypi.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='autofaker',
    version='0.2.4',
    url='https://github.com/christianhelle/autofaker',
    license='MIT License',
    license_files=["LICENSE"],
    author='Christian Helle',
    author_email='christian.helle@outlook.com',
    description='Python library designed to minimize the setup/arrange phase of your unit tests',
    long_description=long_description,
    long_description_content_type='text/markdown',
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    python_requires='>=3.7',
    install_requires=['pandas', 'pyspark', 'faker'],
    entry_points={
        'console_scripts': [
            'python3=autofaker.alias:python3',
        ],
    },
)



import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    name = 'name'
    text = 'test'


class NestedClass:
    id = 123
    name = 'name'
    text = 'test'
    inner = SimpleClass()


class DoubleNestedClass:
    id = 123
    name = 'name'
    text = 'test'
    inner = NestedClass()


class AnonymousNestedClassViaDecoratorTestCase(unittest.TestCase):

    @Autodata.create_arguments(NestedClass)
    def test_create_nested_class_using_decorator_returns_not_none(self, instance):
        self.assertIsNotNone(instance)

    @Autodata.create_arguments(NestedClass)
    def test_create_nested_class_using_decorator_returns_instance(self, instance):
        self.assertIsInstance(instance, NestedClass)

    @Autodata.create_arguments(NestedClass)
    def test_create_nested_class_returns_instance_with_new_values(self, instance):
        self.assertNotEqual(instance.id, NestedClass().id)
        self.assertNotEqual(instance.inner.id, SimpleClass().id)
        self.assertNotEqual(instance.inner.text, SimpleClass().text)

    @Autodata.create_arguments()
    def test_create_nested_class_argument_returns_instance_with_new_values(self, instance: NestedClass):
        self.assertNotEqual(instance.id, NestedClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_anonymous_arguments
    def test_create_anonymous_nested_class_returns_instance_with_new_values(self, instance: NestedClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_fake_arguments
    def test_create_fake_nested_class_returns_instance_with_new_values(self, instance: NestedClass):
        self.assertNotEqual(instance.id, NestedClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)


class AnonymousDoubleNestedClassViaDecoratorWithFakesTestCase(unittest.TestCase):

    @Autodata.create_arguments(DoubleNestedClass, use_fake_data=True)
    def test_create_double_nested_class_using_decorator_returns_not_none(self, instance):
        self.assertIsNotNone(instance)

    @Autodata.create_arguments(DoubleNestedClass, use_fake_data=True)
    def test_create_double_nested_class_using_decorator_returns_instance(self, instance):
        self.assertIsInstance(instance, DoubleNestedClass)

    @Autodata.create_arguments(DoubleNestedClass, use_fake_data=True)
    def test_create_double_nested_class_returns_instance_with_new_values(self, instance):
        self.assertNotEqual(instance.id, DoubleNestedClass().id)
        self.assertNotEqual(instance.inner, DoubleNestedClass().inner)
        self.assertNotEqual(instance.inner.inner.id, SimpleClass().id)
        self.assertNotEqual(instance.inner.inner.text, SimpleClass().text)

    @Autodata.create_arguments(use_fake_data=True)
    def test_create_double_nested_class_argument_using_decorator_returns_not_none(self, instance: DoubleNestedClass):
        self.assertIsNotNone(instance)

    @Autodata.create_arguments(use_fake_data=True)
    def test_create_double_nested_class_argument_using_decorator_returns_instance(self, instance: DoubleNestedClass):
        self.assertIsInstance(instance, DoubleNestedClass)

    @Autodata.create_fake_arguments
    def test_create_double_nested_class_argument_returns_instance_with_new_values(self, instance: DoubleNestedClass):
        self.assertNotEqual(instance.id, DoubleNestedClass().id)
        self.assertNotEqual(instance.inner, DoubleNestedClass().inner)
        self.assertNotEqual(instance.inner.inner.id, SimpleClass().id)
        self.assertNotEqual(instance.inner.inner.text, SimpleClass().text)



import unittest
from datetime import datetime, date

from autofaker import Autodata


class AnonymousPrimitivesViaDecoratorTests(unittest.TestCase):

    @Autodata.create_arguments(str)
    def test_create_str_using_decorator(self, text):
        self.assertIsNotNone(text)

    @Autodata.create_arguments(int)
    def test_create_int_using_decorator(self, number):
        self.assertIsNotNone(number)

    @Autodata.create_arguments(float)
    def test_create_float_using_decorator(self, number):
        self.assertIsNotNone(number)

    @Autodata.create_arguments(bool)
    def test_create_boolean_using_decorator(self, boolean):
        self.assertIsNotNone(boolean)

    @Autodata.create_arguments(datetime)
    def test_create_datetime_using_decorator(self, dt):
        self.assertIsNotNone(dt)

    @Autodata.create_arguments(date)
    def test_create_date_using_decorator(self, d):
        self.assertIsNotNone(d)


class AnonymousPrimitivesViaDecoratorWithFakesTests(unittest.TestCase):

    @Autodata.create_arguments(str, use_fake_data=True)
    def test_create_str_using_decorator(self, text):
        self.assertIsNotNone(text)

    @Autodata.create_arguments(int, use_fake_data=True)
    def test_create_int_using_decorator(self, number):
        self.assertIsNotNone(number)

    @Autodata.create_arguments(float, use_fake_data=True)
    def test_create_float_using_decorator(self, number):
        self.assertIsNotNone(number)

    @Autodata.create_arguments(bool, use_fake_data=True)
    def test_create_boolean_using_decorator(self, boolean):
        self.assertIsNotNone(boolean)

    @Autodata.create_arguments(datetime, use_fake_data=True)
    def test_create_datetime_using_decorator(self, dt):
        self.assertIsNotNone(dt)

    @Autodata.create_arguments(date, use_fake_data=True)
    def test_create_date_using_decorator(self, d):
        self.assertIsNotNone(d)


class MultipleAnonymousPrimitivesViaDecoratorTests(unittest.TestCase):

    @Autodata.create_arguments(str, int, float)
    def test_create_primitives_using_decorator(self, text, number, decimal):
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())

    @Autodata.create_arguments(str, int, float, use_fake_data=True)
    def test_create_primitives_using_decorator_with_fakes(self, text, number, decimal):
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())


class MultipleArgumentsViaDecoratorTests(unittest.TestCase):

    @Autodata.create_anonymous_arguments
    def test_create_anonymous_arguments_using_decorator(self, text: str, number: int, decimal: float):
        print(text)
        print(number)
        print(decimal)
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())

    @Autodata.create_fake_arguments
    def test_create_fake_arguments_using_decorator(self, text: str, number: int, decimal: float):
        print(text)
        print(number)
        print(decimal)
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())

    @Autodata.create_arguments()
    def test_create_arguments_using_decorator(self, text: str, number: int, decimal: float):
        print(text)
        print(number)
        print(decimal)
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())

    @Autodata.create_arguments(use_fake_data=True)
    def test_create_arguments_using_decorator_with_fakes(self, text: str, number: int, decimal: float):
        print(text)
        print(number)
        print(decimal)
        self.assertIsNotNone(text)
        self.assertNotEqual(number, 0)
        self.assertNotEqual(decimal, float())



import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    name = 'name'
    text = 'test'


class AnonymousSimpleClassViaDecoratorTestCase(unittest.TestCase):

    @Autodata.create_arguments(SimpleClass)
    def test_create_simple_class_using_decorator_returns_not_none(self, instance):
        self.assertIsNotNone(instance)

    @Autodata.create_arguments(SimpleClass)
    def test_create_simple_class_using_decorator_returns_instance(self, instance):
        self.assertIsInstance(instance, SimpleClass)

    @Autodata.create_arguments(SimpleClass)
    def test_create_simple_class_returns_instance_with_new_values(self, instance):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_arguments()
    def test_create_simple_class_argument_returns_instance_with_new_values(self, instance: SimpleClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_anonymous_arguments
    def test_create_anonymous_simple_class_returns_instance_with_new_values(self, instance: SimpleClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_fake_arguments
    def test_create_fake_simple_class_returns_instance_with_new_values(self, instance: SimpleClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)


class AnonymousSimpleClassViaDecoratorWithFakesTestCase(unittest.TestCase):

    @Autodata.create_arguments(SimpleClass, use_fake_data=True)
    def test_create_simple_class_using_decorator_returns_not_none(self, instance):
        self.assertIsNotNone(instance)

    @Autodata.create_arguments(SimpleClass, use_fake_data=True)
    def test_create_simple_class_using_decorator_returns_instance(self, instance):
        self.assertIsInstance(instance, SimpleClass)

    @Autodata.create_arguments(SimpleClass, use_fake_data=True)
    def test_create_simple_class_returns_instance_with_new_values(self, instance):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_arguments(use_fake_data=True)
    def test_create_simple_class_argument_returns_instance_with_new_values(self, instance: SimpleClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)

    @Autodata.create_fake_arguments
    def test_create_fake_simple_class_returns_instance_with_new_values(self, instance: SimpleClass):
        self.assertNotEqual(instance.id, SimpleClass().id)
        self.assertNotEqual(instance.name, SimpleClass().name)
        self.assertNotEqual(instance.text, SimpleClass().text)



import dataclasses

from autofaker.attributes import Attributes
from autofaker.builtins import IntegerGenerator, FloatGenerator, BooleanGenerator
from autofaker.dates import DatetimeGenerator, DateGenerator
from autofaker.fakes import FakeStringGenerator, StringGenerator, FakeIntegerGenerator, TypeDataGeneratorBase


class TypeDataGenerator:
    @staticmethod
    def create(t, field_name: str = None, use_fake_data: bool = False) -> TypeDataGeneratorBase:
        type_name = t.__name__
        if type_name == 'int':
            return FakeIntegerGenerator() \
                if field_name is not None and use_fake_data is True \
                else IntegerGenerator()
        elif type_name == 'str':
            return FakeStringGenerator(field_name) \
                if field_name is not None and use_fake_data is True \
                else StringGenerator()
        elif type_name == 'float':
            return FloatGenerator()
        elif type_name == 'bool':
            return BooleanGenerator()
        elif type_name == 'datetime':
            return DatetimeGenerator()
        elif type_name == 'date':
            return DateGenerator()
        elif type_name == 'list':
            return ListGenerator(t)
        else:
            return DataClassGenerator(t, use_fake_data=use_fake_data) \
                if dataclasses.is_dataclass(t) \
                else ClassGenerator(t, use_fake_data=use_fake_data)


class DataClassGenerator(TypeDataGeneratorBase):
    def __init__(self, cls, use_fake_data: bool = False):
        self.use_fake_data = use_fake_data
        self.cls = cls

    def generate(self):
        args = []
        fields = dataclasses.fields(self.cls)
        for field in fields:
            generator = TypeDataGenerator.create(field.type, field.name, use_fake_data=self.use_fake_data)
            args.append((field.name, field.type, generator.generate()))
        name = self.cls.__module__ + '.' + self.cls.__qualname__
        instance = dataclasses.make_dataclass(name, args)
        return instance


class ClassGenerator(TypeDataGeneratorBase):
    def __init__(self, cls, use_fake_data: bool = False):
        self.use_fake_data = use_fake_data
        self.instance = cls()

    def generate(self):
        attributes = Attributes(self.instance)
        members = attributes.get_members()
        for member in members:
            attr = attributes.get_attribute(member)
            if type(attr).__name__ == 'list':
                for i in range(len(attr)):
                    generator = TypeDataGenerator.create(type(attr[i]), use_fake_data=self.use_fake_data)
                    attr[i] = generator.generate()
            else:
                generator = TypeDataGenerator.create(type(attr), member, use_fake_data=self.use_fake_data)
                attributes.set_value(member, generator.generate())
        return self.instance


class ListGenerator(TypeDataGeneratorBase):
    def __init__(self, t, use_fake_data: bool = False):
        self.use_fake_data = use_fake_data
        self.instance = t()

    def generate(self):
        items = []
        for item in self.instance:
            generator = TypeDataGenerator.create(item, use_fake_data=self.use_fake_data)
            value = generator.generate()
            items.append(value)
        return items
